@@ -78,6 +78,8 @@ class PrivateConstants:
     STEPPER_GET_DISTANCE_TO_GO = 52
     STEPPER_GET_TARGET_POSITION = 53
     GET_FEATURES = 54
+    SONAR_DISABLE = 55
+    SONAR_ENABLE = 56
 
     # reports
     # debug data from Arduino
@@ -101,7 +103,7 @@ class PrivateConstants:
     FEATURES = 20
     DEBUG_PRINT = 99
 
-    TELEMETRIX_VERSION = "1.10"
+    TELEMETRIX_VERSION = "1.20"
 
     # reporting control
     REPORTING_DISABLE_ALL = 0
